==> haskell-servant-server-0.13.0.1-84-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-server
version: 0.13.0.1
id: servant-server-0.13.0.1-BqWEaKvrvRI542Ft4VqNDb
key: servant-server-0.13.0.1-BqWEaKvrvRI542Ft4VqNDb
license: BSD-3-Clause
copyright: 2014-2016 Zalora South East Asia Pte Ltd, Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
author: Servant Contributors
homepage: http://haskell-servant.readthedocs.org/
synopsis: A family of combinators for defining webservices APIs and serving them
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://haskell-servant.readthedocs.org/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>
category: Servant, Web
abi: 30a524e362bd437c18b3d1b14cf80179
exposed: True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Internal Servant.Server.Internal.BasicAuth
    Servant.Server.Internal.Context Servant.Server.Internal.Handler
    Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServantErr Servant.Utils.StaticFiles
import-dirs: /usr/lib/ghc-8.4.3/site-local/servant-server-0.13.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/servant-server-0.13.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/servant-server-0.13.0.1
hs-libraries: HSservant-server-0.13.0.1-BqWEaKvrvRI542Ft4VqNDb
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0 mtl-2.2.2
    text-1.2.3.0 transformers-0.5.5.0 filepath-1.4.2
    servant-0.13.0.1-EZ7WK8vh9h5EQQ4y4V51BL
    aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL
    base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ
    attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi
    http-api-data-0.3.8.1-HsmKi4q9sry407CCb10xd2
    http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf
    http-types-0.12.1-C6lpBNl8s0n56pfgsv3YNb
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    monad-control-1.0.2.3-4ughhLHj9Ka6p4m5wwuexX
    network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG
    string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT
    system-filepath-0.4.14-9jYDOZRDoMqIkxdisSNvm4
    resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    transformers-base-0.4.5.2-CPMQOTuCPA6G978LVAIlzh
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    wai-3.2.1.2-LYrgj5pDFEpLGOS1bmSP2u
    wai-app-static-3.1.6.2-KQf60VWncteC72q1HLasrI
    warp-3.2.25-EI1rVbUz7ff1gLuLQn7Xlf
    word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             servant-0.13.0.1-EZ7WK8vh9h5EQQ4y4V51BL=8b1bdfb5ef423c970fbca44faaf73c14
             aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL=912860ab3519756596367ddae154025c
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=d7511a9b0b5b14c2ec3659e1cd285aec
             attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE=4221e97be581adbf81c2554dcbaa8ab5
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi=b417f0870e3d66d725c431d901a306c8
             http-api-data-0.3.8.1-HsmKi4q9sry407CCb10xd2=b176cb3071cad242a7d16935dd083e98
             http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf=483bd81a950f6e9e13c6265205a34bbd
             http-types-0.12.1-C6lpBNl8s0n56pfgsv3YNb=976aaa70f9b7212c24b31f28f22b380a
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
             monad-control-1.0.2.3-4ughhLHj9Ka6p4m5wwuexX=ccfd06c57089143c2e021ca11cc4fff5
             network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu=43a70846fe67ebce9998ba267f800e6d
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=42026212d0dad8beaed25fde58365be8
             split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG=cdf77c47c599317cfa01d2d98185c5d3
             string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT=7baf46c0fb04e29c804c22c4ec2f96ad
             system-filepath-0.4.14-9jYDOZRDoMqIkxdisSNvm4=14adf804eb2ee22bef25db71be916c66
             resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q=b5273090c64c1efd0c4504885cc2bdef
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             transformers-base-0.4.5.2-CPMQOTuCPA6G978LVAIlzh=24d243b13204b0d99b0f7fc5f56cecfb
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             wai-3.2.1.2-LYrgj5pDFEpLGOS1bmSP2u=d9fba6511abb80273dc6e619fc5c09ff
             wai-app-static-3.1.6.2-KQf60VWncteC72q1HLasrI=516edce246f10b02fc40940a2d55721e
             warp-3.2.25-EI1rVbUz7ff1gLuLQn7Xlf=2fd49733c069bd988a5de1e82e539514
             word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU=17353ed56fb5c760af7bb1df1e6d2f4c
haddock-interfaces: /usr/share/doc/haskell-servant-server/html/servant-server.haddock
haddock-html: /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-server-0.13.0.1-89-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-server
version: 0.13.0.1
id: servant-server-0.13.0.1-1curXJC5qBaEytY3b89QxT
key: servant-server-0.13.0.1-1curXJC5qBaEytY3b89QxT
license: BSD-3-Clause
copyright: 2014-2016 Zalora South East Asia Pte Ltd, Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
author: Servant Contributors
homepage: http://haskell-servant.readthedocs.org/
synopsis: A family of combinators for defining webservices APIs and serving them
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://haskell-servant.readthedocs.org/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>
category: Servant, Web
abi: cce94f31647f8cb86d636ca35e2878ff
exposed: True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Internal Servant.Server.Internal.BasicAuth
    Servant.Server.Internal.Context Servant.Server.Internal.Handler
    Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServantErr Servant.Utils.StaticFiles
import-dirs: /usr/lib/ghc-8.4.3/site-local/servant-server-0.13.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/servant-server-0.13.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/servant-server-0.13.0.1
hs-libraries: HSservant-server-0.13.0.1-1curXJC5qBaEytY3b89QxT
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0 mtl-2.2.2
    text-1.2.3.0 transformers-0.5.5.0 filepath-1.4.2
    servant-0.13.0.1-Ckx0UJHfhXx70LTX08yRGg
    aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL
    base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ
    attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi
    http-api-data-0.3.8.1-4IwrFIhrCiACTGPPbTc1JH
    http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf
    http-types-0.12.1-C6lpBNl8s0n56pfgsv3YNb
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    monad-control-1.0.2.3-4ughhLHj9Ka6p4m5wwuexX
    network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG
    string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT
    system-filepath-0.4.14-9jYDOZRDoMqIkxdisSNvm4
    resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    transformers-base-0.4.5.2-CPMQOTuCPA6G978LVAIlzh
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    wai-3.2.1.2-LYrgj5pDFEpLGOS1bmSP2u
    wai-app-static-3.1.6.2-4DxYMFuwMJ61p2G04nse1V
    warp-3.2.25-2s20RyHxHqfAud2HZEMk56
    word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             servant-0.13.0.1-Ckx0UJHfhXx70LTX08yRGg=e995c8f5701e78637e07f8d94be1cdf4
             aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL=912860ab3519756596367ddae154025c
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=d7511a9b0b5b14c2ec3659e1cd285aec
             attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE=4221e97be581adbf81c2554dcbaa8ab5
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi=b417f0870e3d66d725c431d901a306c8
             http-api-data-0.3.8.1-4IwrFIhrCiACTGPPbTc1JH=2c5c3a8b61918ce3bc6e5a36791f2ffa
             http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf=483bd81a950f6e9e13c6265205a34bbd
             http-types-0.12.1-C6lpBNl8s0n56pfgsv3YNb=976aaa70f9b7212c24b31f28f22b380a
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
             monad-control-1.0.2.3-4ughhLHj9Ka6p4m5wwuexX=ccfd06c57089143c2e021ca11cc4fff5
             network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu=43a70846fe67ebce9998ba267f800e6d
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=42026212d0dad8beaed25fde58365be8
             split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG=cdf77c47c599317cfa01d2d98185c5d3
             string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT=7baf46c0fb04e29c804c22c4ec2f96ad
             system-filepath-0.4.14-9jYDOZRDoMqIkxdisSNvm4=14adf804eb2ee22bef25db71be916c66
             resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q=b5273090c64c1efd0c4504885cc2bdef
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             transformers-base-0.4.5.2-CPMQOTuCPA6G978LVAIlzh=24d243b13204b0d99b0f7fc5f56cecfb
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             wai-3.2.1.2-LYrgj5pDFEpLGOS1bmSP2u=d9fba6511abb80273dc6e619fc5c09ff
             wai-app-static-3.1.6.2-4DxYMFuwMJ61p2G04nse1V=eb5dbf4043e0d6c9cc80c83ec63904f8
             warp-3.2.25-2s20RyHxHqfAud2HZEMk56=e2bcc4f40c7cc28bde4b8aaff3371257
             word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU=17353ed56fb5c760af7bb1df1e6d2f4c
haddock-interfaces: /usr/share/doc/haskell-servant-server/html/servant-server.haddock
haddock-html: /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
